pub struct QueuedArrayCounter { /* private fields */ }Expand description
Tracks the number of queued (in-flight) arrays across non-blocking plugins. Used by drivers to perform a bounded wait at end of acquisition.
Implementations
Sourceimpl QueuedArrayCounter
impl QueuedArrayCounter
Sourcepub fn wait_until_zero(&self, timeout: Duration) -> bool
pub fn wait_until_zero(&self, timeout: Duration) -> bool
Wait until count reaches zero, or timeout expires.
Returns true if count is zero, false on timeout.